"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_webview_1 = __importDefault(require("react-native-webview"));
class KakaoLink extends react_1.default.PureComponent {
    constructor() {
        super(...arguments);
        this.webview = react_1.default.createRef();
        this.sendDefault = (template) => {
            const script = `window.Kakao.Link.sendDefault(${JSON.stringify(template)}); true;`;
            this.webview.current?.injectJavaScript(script);
        };
        this.sendCustom = (template) => {
            const script = `window.Kakao.Link.sendCustom(${JSON.stringify(template)}); true;`;
            this.webview.current?.injectJavaScript(script);
        };
        this.handleScheme = ({ url }) => {
            const link = url.startsWith("intent:") ? url.replace("intent:", "") : url;
            if (link.startsWith("kakaolink://")) {
                react_native_1.Linking.openURL(link).catch(this.props.onShareFailure);
                return false;
            }
            return true;
        };
    }
    get source() {
        return {
            baseUrl: this.props.whitelistedDomain,
            html: `
<html>
    <meta http-equiv="content-type" content="text/html; charset=utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <script src="https://developers.kakao.com/sdk/js/kakao.js"></script>
    <script>
        window.Kakao.init("${this.props.webKakaoKey}");
    </script>
</html>`
        };
    }
    render() {
        return (<react_native_webview_1.default originWhitelist={["*"]} onShouldStartLoadWithRequest={this.handleScheme} style={styles.webview} ref={this.webview} allowsInlineMediaPlayback={false} source={this.source}/>);
    }
}
exports.default = KakaoLink;
const styles = react_native_1.StyleSheet.create({
    webview: { flex: 0, width: 0, height: 0, opacity: 0 }
});
//# sourceMappingURL=index.js.map